bayespy.inference.vmp.nodes.gamma.GammaMoments.compute_dims_from_values
=======================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gamma

.. automethod:: GammaMoments.compute_dims_from_values